Enum Key
pub enum Key<C = SmolStr> {
Named(Named),
Character(C),
Unidentified,
}Expand description
A key on the keyboard.
This is mostly the Key type found in winit.
Variants
Named(Named)
A key with an established name.
Character(C)
A key string that corresponds to the character typed by the user, taking into account the user’s current locale setting, and any system-level keyboard mapping overrides that are in effect.
Unidentified
An unidentified key.
Implementations
impl Key
impl Key
pub fn as_ref(&self) -> Key<&str>
pub fn as_ref(&self) -> Key<&str>
Convert Key::Character(SmolStr) to Key::Character(&str) so you can more easily match on
Key. All other variants remain unchanged.
pub fn to_latin(&self, physical_key: Physical) -> Option<char>
pub fn to_latin(&self, physical_key: Physical) -> Option<char>
Tries to convert this logical Key into its latin character, using the
Physical key provided for translation if it isn’t already in latin.
Returns None if no latin variant could be found.
use iced_core::keyboard::key::{Key, Named, Physical, Code};
// Latin c
assert_eq!(
Key::Character("c".into()).to_latin(Physical::Code(Code::KeyC)),
Some('c'),
);
// Cyrillic с
assert_eq!(
Key::Character("с".into()).to_latin(Physical::Code(Code::KeyC)),
Some('c'),
);
// Arrow Left
assert_eq!(
Key::Named(Named::ArrowLeft).to_latin(Physical::Code(Code::ArrowLeft)),
None,
);Trait Implementations
impl<'de, C> Deserialize<'de> for Key<C>where
C: Deserialize<'de>,
impl<'de, C> Deserialize<'de> for Key<C>where
C: Deserialize<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Key<C>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Key<C>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<C> Ord for Key<C>where
C: Ord,
impl<C> Ord for Key<C>where
C: Ord,
impl<C> PartialOrd for Key<C>where
C: PartialOrd,
impl<C> PartialOrd for Key<C>where
C: PartialOrd,
impl<C> Serialize for Key<C>where
C: Serialize,
impl<C> Serialize for Key<C>where
C: Serialize,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl<C> Eq for Key<C>where
C: Eq,
impl<C> StructuralPartialEq for Key<C>